import {Component, EventEmitter, OnInit, Output} from '@angular/core';
import {AlarmService} from '../../alarm.service';
import {
    FormBuilder,
    FormControl,
    FormGroup,
    ValidationErrors,
    Validators
} from '@angular/forms';
import {NzMessageService} from 'ng-zorro-antd';

@Component({
    selector: 'smart-alarm-group',
    templateUrl: './alarm-group.component.html',
    styles: []
})
export class AlarmGroupComponent implements OnInit {
    @Output() add = new EventEmitter<any>();

    title;
    isVisible = false;

    validateForm: FormGroup;
    name;
    description;

    constructor(private alarmSer:AlarmService,private fb:FormBuilder,
                private message:NzMessageService) {
    }

    ngOnInit() {
        this.initForm();
    }

    //新增告警组
    addModal() {
        this.title = '新增告警组';
        this.isVisible = true;
    }

    //编辑告警组
    editModal() {
        this.title = '编辑告警组';
        this.isVisible = true;
    }

    //取消
    handleCancel() {
        this.isVisible = false;
    }

    //确定
    handleOk() {
        // console.log(this.validateForm.valid);
        for(const i in this.validateForm.controls) {
            this.validateForm.controls[ i ].markAsDirty();
            this.validateForm.controls[ i ].updateValueAndValidity();
        }
        if(this.validateForm.invalid){
            return false;
        }

        this.alarmSer.alertGroupCreate(this.validateForm.value).subscribe(
            (res)=>{
                if(res.errCode == 10000){
                    this.isVisible = false;
                    this.add.emit();
                }
                this.message.info(res.errMsg);
            }
        )
    }

    //初始化
    initForm(){
        this.validateForm = this.fb.group({
            name:[null,[Validators.required]],
            description:[null]
        })
    }

}
